// Set default values directly as globals
const DEFAULT_TARIFF_PERCENTAGE = 125;

// On installation or update
chrome.runtime.onInstalled.addListener(function(details) {
  if (details.reason === 'install') {
    console.log('Show Tariffs extension installed');
    
    // Open welcome page
    chrome.tabs.create({
      url: 'https://showtariffs.com/'
    });
  } else if (details.reason === 'update') {
    const thisVersion = chrome.runtime.getManifest().version;
    console.log('Updated from ' + details.previousVersion + ' to ' + thisVersion);
  }
});

// Listen for commands from context menu, shortcuts, etc.
chrome.action.onClicked.addListener(function(tab) {
  // This only fires when the extension has no popup
  // and user clicks the extension icon
  
  // If we're on a product page, send a message to display tariff info
  if (isProductPage(tab.url)) {
    chrome.tabs.sendMessage(tab.id, { 
      action: "displayTariffInfo",
      tariffPercentage: DEFAULT_TARIFF_PERCENTAGE
    });
  }
});

// Function to check if URL is a product page (Amazon or Walmart)
function isProductPage(url) {
  return isAmazonProductPage(url) || isWalmartProductPage(url);
}

// Function to check if URL is an Amazon product page
function isAmazonProductPage(url) {
  return url && url.includes('amazon.com') && 
         (url.includes('/dp/') || url.includes('/gp/product/'));
}

// Check if this is a Walmart product page
function isWalmartProductPage() {
  const url = window.location.href;
  
  // First check if we're on walmart.com
  if (!url.includes('walmart.com')) {
    return false;
  }
  
  // Check for /ip/ in the URL (all product pages have this in the path)
  if (url.includes('/ip/')) {
    return true;
  }
  
  // Check for /items/ pattern
  if (url.includes('/items/')) {
    return true;
  }
  
  // Look for signature Walmart product page elements
  const walmartProductElements = [
    // Product title elements
    'h1[itemprop="name"]',
    'h1.prod-ProductTitle',
    'h1.f3',
    'h1.b lh-copy',
    'h1.w_Y_vW',
    'h1[data-automation="product-title"]',
    
    // Price elements
    '[data-automation="current-price"]',
    '[data-automation="product-price"]',
    '[data-automation="buybox-price"]',
    '.price-characteristic',
    
    // Buy box elements
    '.prod-ProductCTA--primary',
    '[data-automation="add-to-cart"]',
    '[data-automation="buy-now"]',
    '.add-to-cart-btn'
  ];
  
  // Return true if any of these elements exist on the page
  for (const selector of walmartProductElements) {
    if (document.querySelector(selector)) {
      return true;
    }
  }
  
  return false;
}

// Listen for messages from content scripts or popup
chrome.runtime.onMessage.addListener(function(request, sender, sendResponse) {
  if (request.action === "getTariffPercentage") {
    // Return the default tariff percentage
    sendResponse({ tariffPercentage: DEFAULT_TARIFF_PERCENTAGE });
  }
  
  return true;
});