// Show Tariffs content script with direct ST-US search

// Default settings
const DEFAULT_TARIFF_PERCENTAGE = 125;
const AUTO_DISPLAY = true;

// Function to handle messages from popup
chrome.runtime.onMessage.addListener(function(request, sender, sendResponse) {
  console.log("Content script received message:", request);
  if (request.action === "getProductInfo") {
    const productInfo = extractProductInfo();
    sendResponse(productInfo);
  } 
  else if (request.action === "updateTariff") {
    // Update the display with the new tariff percentage
    updateTariffDisplay(request.tariffPercentage);
    sendResponse({success: true});
  }
  else if (request.action === "displayTariffInfo") {
    // Display tariff info with specified percentage or default
    const percentage = request.tariffPercentage || DEFAULT_TARIFF_PERCENTAGE;
    displayTariffInfo(percentage);
    sendResponse({success: true});
  }
  return true; // Indicates we want to send a response asynchronously
});

// Function that extracts product information from the page
function extractProductInfo() {
  try {
    console.log("Extracting product info...");
    
    // Check if we're on Amazon or Walmart
    const isAmazonPage = isAmazonProductPage();
    const isWalmartPage = isWalmartProductPage();
    
    if (!isAmazonPage && !isWalmartPage) {
      return {
        success: false,
        error: 'Not a supported product page'
      };
    }
    
    // Extract product details based on site
    if (isAmazonPage) {
      return extractAmazonProductInfo();
    } else if (isWalmartPage) {
      return extractWalmartProductInfo();
    }
    
  } catch (error) {
    console.error("Error extracting product info:", error);
    return {success: false, error: error.message};
  }
}

// Function to extract Amazon product information
function extractAmazonProductInfo() {
  // Get product title - improved selector strategy
  let title = '';
  const titleSelectors = [
    '#productTitle',
    '.product-title',
    '.a-size-large.product-title-word-break',
    'h1.a-size-large'
  ];
  
  for (const selector of titleSelectors) {
    const element = document.querySelector(selector);
    if (element) {
      title = element.textContent.trim();
      console.log("Found Amazon title:", title);
      break;
    }
  }
  
  // Get product category if available
  const category = extractAmazonCategory();
  console.log("Product category:", category);
  
  // Check for ST tags in product description
  const stTagInfo = parseSTTags();
  console.log("ST Tag info:", stTagInfo);
  
  // Get product ASIN if available
  const asin = extractAmazonASIN();
  console.log("Product ASIN:", asin);
  
  // Extract any search term from the URL
  const searchQuery = extractSearchQuery();
  console.log("Search query:", searchQuery);
  
  // Enhanced price extraction with multiple selector strategies
  const price = extractAmazonPrice();
  console.log("Extracted Amazon price:", price);
  
  if (price) {
    return {
      success: true,
      title: title,
      price: price,
      asin: asin,
      category: category,
      searchQuery: searchQuery,
      retailer: 'amazon',
      stTagInfo: stTagInfo  // Include ST tag info if found
    };
  }
  
  console.log("Could not parse Amazon price");
  return {
    success: false, 
    error: 'Could not parse price',
    stTagInfo: stTagInfo  // Still include ST tag info even if price parsing failed
  };
}

// Function to extract Amazon product category
function extractAmazonCategory() {
  const categoryElements = document.querySelectorAll('#wayfinding-breadcrumbs_feature_div .a-link-normal');
  if (categoryElements && categoryElements.length > 0) {
    // Get the last category (usually the most specific)
    const lastCategory = categoryElements[categoryElements.length - 1];
    return lastCategory.textContent.trim();
  }
  
  return null;
}

// Function to extract search query from URL
function extractSearchQuery() {
  const url = window.location.href;
  
  // Check for Amazon search
  if (url.includes('amazon.com/s?') || url.includes('amazon.com/s/?')) {
    const urlParams = new URLSearchParams(window.location.search);
    return urlParams.get('k') || urlParams.get('field-keywords') || '';
  }
  
  // Check for Walmart search
  if (url.includes('walmart.com/search?') || url.includes('walmart.com/search/?')) {
    const urlParams = new URLSearchParams(window.location.search);
    return urlParams.get('q') || '';
  }
  
  return '';
}

// Function to extract Walmart product information
function extractWalmartProductInfo() {
  // Get product title
  let title = '';
  const titleSelectors = [
    'h1[itemprop="name"]',
    'h1.prod-ProductTitle',
    'h1.f3',
    'h1.b lh-copy',
    'h1.w_Y_vW',  // Current selector in 2025
    'h1[data-automation="product-title"]'
  ];
  
  for (const selector of titleSelectors) {
    const element = document.querySelector(selector);
    if (element) {
      title = element.textContent.trim();
      console.log("Found Walmart title:", title);
      break;
    }
  }
  
  // Get product category if available
  const category = extractWalmartCategory();
  console.log("Walmart category:", category);
  
  // Get product ID if available (Walmart's item number)
  const itemId = extractWalmartItemId();
  console.log("Product Item ID:", itemId);
  
  // Extract any search term from the URL
  const searchQuery = extractSearchQuery();
  console.log("Search query:", searchQuery);
  
  // Extract price
  const price = extractWalmartPrice();
  console.log("Extracted Walmart price:", price);
  
  // Check for ST tags in product description
  const stTagInfo = parseSTTags('walmart');
  console.log("ST Tag info:", stTagInfo);
  
  if (price) {
    return {
      success: true,
      title: title,
      price: price,
      itemId: itemId,
      category: category,
      searchQuery: searchQuery,
      retailer: 'walmart',
      stTagInfo: stTagInfo
    };
  }
  
  console.log("Could not parse Walmart price");
  return {
    success: false, 
    error: 'Could not parse price',
    stTagInfo: stTagInfo
  };
}

// Function to extract Walmart product category
function extractWalmartCategory() {
  const categoryElements = document.querySelectorAll('.breadcrumb span');
  if (categoryElements && categoryElements.length > 0) {
    // Get the last category (usually the most specific)
    const lastCategory = categoryElements[categoryElements.length - 1];
    return lastCategory.textContent.trim();
  }
  
  return null;
}

// Extract Amazon price
function extractAmazonPrice() {
  // Array of selectors for various Amazon price elements
  const priceSelectors = [
    '.a-price .a-offscreen',
    '#priceblock_ourprice',
    '#priceblock_dealprice',
    '#corePrice_feature_div .a-price',
    '.a-price .a-price-whole',
    '#price_inside_buybox',
    '.apexPriceToPay .a-offscreen',
    '#sns-base-price',
    '.a-section.a-spacing-small .a-price'
  ];
  
  // Try each selector
  for (const selector of priceSelectors) {
    const element = document.querySelector(selector);
    if (element) {
      const priceText = element.textContent.trim();
      // Clean up the price string and convert to number
      const cleanPrice = priceText.replace(/[^0-9.]/g, '');
      const price = parseFloat(cleanPrice);
      
      if (!isNaN(price)) {
        return price;
      }
    }
  }
  
  // Special case for .a-price with .a-price-whole and .a-price-fraction
  const wholePart = document.querySelector('.a-price .a-price-whole');
  const fractionPart = document.querySelector('.a-price .a-price-fraction');
  if (wholePart && fractionPart) {
    const priceStr = wholePart.textContent.trim() + '.' + fractionPart.textContent.trim();
    const cleanPrice = priceStr.replace(/[^0-9.]/g, '');
    const price = parseFloat(cleanPrice);
    
    if (!isNaN(price)) {
      return price;
    }
  }
  
  return null;
}

// Extract Walmart price
function extractWalmartPrice() {
  console.log("Starting Walmart price extraction...");
  
  // Array of selectors for various Walmart price elements
  const priceSelectors = [
    '[data-automation="current-price"]',
    '[data-automation="product-price"]',
    '[data-automation="buybox-price"]',
    '.price-characteristic',
    '.b black f5',
    '.w_BY_n', // Current selector in 2025
    // Add these new selectors
    '.f1-m',
    '.f2-m',
    '.price-main',
    '[itemprop="price"]',
    '[data-testid="price"]',
    '.price-group'
  ];
  
  // Try each selector
  for (const selector of priceSelectors) {
    const element = document.querySelector(selector);
    if (element) {
      console.log("Found price element with selector:", selector);
      const priceText = element.textContent.trim();
      console.log("Price text found:", priceText);
      
      // Clean up the price string and convert to number
      const cleanPrice = priceText.replace(/[^0-9.]/g, '');
      console.log("Cleaned price:", cleanPrice);
      
      const price = parseFloat(cleanPrice);
      console.log("Parsed price:", price);
      
      if (!isNaN(price)) {
        console.log("Successfully extracted price:", price);
        return price;
      }
    }
  }
  
  // Try a more complex approach for Walmart's price format (dollars + cents)
  const priceCharacteristic = document.querySelector('.price-characteristic');
  const priceMantissa = document.querySelector('.price-mantissa');
  
  if (priceCharacteristic && priceMantissa) {
    console.log("Found price characteristic and mantissa");
    const dollars = priceCharacteristic.textContent.trim();
    const cents = priceMantissa.textContent.trim();
    const priceStr = dollars + '.' + cents;
    console.log("Constructed price string:", priceStr);
    
    const price = parseFloat(priceStr);
    console.log("Parsed composite price:", price);
    
    if (!isNaN(price)) {
      console.log("Successfully extracted composite price:", price);
      return price;
    }
  }
  
  // Last resort: Try to find any element with a number that looks like a price
  console.log("Using last resort price finding method...");
  const possiblePriceElements = document.querySelectorAll('.price, [class*="price"], [class*="Price"]');
  
  for (const element of possiblePriceElements) {
    const text = element.textContent.trim();
    if (text.includes('$')) {
      console.log("Found potential price element:", text);
      const cleanPrice = text.replace(/[^0-9.]/g, '');
      const price = parseFloat(cleanPrice);
      
      if (!isNaN(price) && price > 0) {
        console.log("Successfully extracted fallback price:", price);
        return price;
      }
    }
  }
  
  console.log("Failed to extract Walmart price");
  return null;
}

// Function to extract ASIN from Amazon URL or page
function extractAmazonASIN() {
  const url = window.location.href;
  
  // Try to extract from URL first
  const asinPattern = /\/(?:dp|gp\/product)\/([A-Z0-9]{10})/;
  const match = url.match(asinPattern);
  
  if (match && match[1]) {
    return match[1];
  }
  
  // Alternative method: check for data attribute
  const asinElement = document.querySelector('[data-asin]');
  if (asinElement && asinElement.getAttribute('data-asin')) {
    return asinElement.getAttribute('data-asin');
  }
  
  return null;
}

// Function to extract Walmart item ID from URL or page
function extractWalmartItemId() {
  const url = window.location.href;
  
  // Try to extract from URL first - Walmart URLs typically contain /ip/ followed by product name and item ID
  const itemIdPattern = /\/ip\/(?:.*?)\/(\d+)/;
  const match = url.match(itemIdPattern);
  
  if (match && match[1]) {
    return match[1];
  }
  
  // Try alternate URL pattern
  const alternatePattern = /\/items\/(\d+)/;
  const alternateMatch = url.match(alternatePattern);
  
  if (alternateMatch && alternateMatch[1]) {
    return alternateMatch[1];
  }
  
  // Look for item ID in meta tags or data attributes
  const itemIdElement = document.querySelector('[data-item-id]');
  if (itemIdElement && itemIdElement.getAttribute('data-item-id')) {
    return itemIdElement.getAttribute('data-item-id');
  }
  
  return null;
}

function parseSTTags(retailer = 'amazon') {
  try {
    let description = '';
    
    if (retailer === 'amazon') {
      // Multiple selectors for Amazon product description elements
      const descriptionSelectors = [
        '#productDescription', 
        '#feature-bullets', 
        '#detail-bullets', 
        '.a-expander-content',
        '.product-description',
        '#detailBullets',
        '.product-facts'
      ];
      
      // Try each selector
      for (const selector of descriptionSelectors) {
        const element = document.querySelector(selector);
        if (element) {
          description += element.textContent.trim() + ' ';
        }
      }
    } else if (retailer === 'walmart') {
      // Multiple selectors for Walmart product description elements
      const descriptionSelectors = [
        '.product-description-container',
        '[data-automation="product-description"]',
        '[data-automation="productDescription"]',
        '.prod-ProductDescription',
        '.d_nWo', // Current selector in 2025
        '.about-product',
        '.specification-table',
        '.product-short-description'
      ];
      
      // Try each selector
      for (const selector of descriptionSelectors) {
        const element = document.querySelector(selector);
        if (element) {
          description += element.textContent.trim() + ' ';
        }
      }
    }
    
    if (!description) {
      console.log("No product description found");
      return null;
    }
    
    console.log("Found product description");
    
    // Check for US-made product tag
    const usMadeMatch = description.match(/ST-US\b/);
    if (usMadeMatch) {
      console.log("Found US-made product tag");
      return {
        isUSMade: true,
        tariffPercentage: 0,
        countryBreakdown: null
      };
    }
    
    // Check for complex country breakdown
    // Format: ST-XX-CC-YY-CC-YY-CC-YY where XX is tariff %, CC is country code, YY is percentage
    const complexMatch = description.match(/ST-(\d+)-([A-Z]{2}-\d+)(-[A-Z]{2}-\d+)*/);
    if (complexMatch) {
      console.log("Found complex ST tag:", complexMatch[0]);
      
      // Extract tariff percentage
      const tariffPercentage = parseInt(complexMatch[1]);
      
      // Parse country breakdown
      const countryParts = complexMatch[0].substring(complexMatch[0].indexOf('-', 3) + 1).split('-');
      const countryBreakdown = [];
      
      for (let i = 0; i < countryParts.length; i += 2) {
        if (i + 1 < countryParts.length) {
          countryBreakdown.push({
            countryCode: countryParts[i],
            percentage: parseInt(countryParts[i + 1])
          });
        }
      }
      
      return {
        isUSMade: false,
        tariffPercentage: tariffPercentage,
        countryBreakdown: countryBreakdown
      };
    }
    
    // Check for simple tariff percentage tag
    const simpleMatch = description.match(/ST-(\d+)\b/);
    if (simpleMatch) {
      console.log("Found simple tariff tag:", simpleMatch[0]);
      return {
        isUSMade: false,
        tariffPercentage: parseInt(simpleMatch[1]),
        countryBreakdown: null
      };
    }
    
    console.log("No ST tags found in description");
    return null;
  } catch (error) {
    console.error("Error parsing ST tags:", error);
    return null;
  }
}

// Function to update the tariff display when the percentage changes
function updateTariffDisplay(tariffPercentage) {
  console.log("Updating tariff display with percentage:", tariffPercentage);
  
  // Remove existing tariff box if present
  const existingBox = document.getElementById('show-tariffs-box');
  if (existingBox) {
    existingBox.remove();
  }
  
  // Display with new percentage
  displayTariffInfo(tariffPercentage);
}

// Function to create a direct search URL for products with ST-US tag
// With description parsing for Walmart only
function createDirectSearchURL(productInfo) {
  // Determine which retailer we're on
  const currentRetailer = productInfo.retailer || 
                         (isAmazonProductPage() ? 'amazon' : 'walmart');
  
  // Get search terms based on retailer
  let searchTerms = "";
  
  if (currentRetailer === 'amazon') {
    // Original method for Amazon
    // Try to use any existing search query first
    if (productInfo.searchQuery && productInfo.searchQuery.length > 0) {
      searchTerms = productInfo.searchQuery;
    } 
    // Otherwise, use the product title
    else if (productInfo.title) {
      // Extract key terms from title (remove common words)
      const titleWords = productInfo.title.split(' ');
      const filteredWords = titleWords.filter(word => 
        word.length > 2 && 
        !['the', 'and', 'for', 'with', 'this', 'that', 'from', 'your'].includes(word.toLowerCase())
      );
      
      // Use up to 3 words from the title
      searchTerms = filteredWords.slice(0, 3).join(' ');
      
      // Add category if available
      if (productInfo.category && productInfo.category.length > 0) {
        searchTerms += ' ' + productInfo.category;
      }
    }
  } 
  else if (currentRetailer === 'walmart') {
    // Enhanced method for Walmart - Use description for better searches
    
    // Try to use any existing search query first
    if (productInfo.searchQuery && productInfo.searchQuery.length > 0) {
      searchTerms = productInfo.searchQuery;
    } 
    // Otherwise, extract terms from description
    else {
      // Get product description
      const description = extractWalmartProductDescription();
      
      // Parse description for key terms if available
      if (description) {
        // Extract meaningful words from description
        const descWords = description.split(/\s+/);
        
        // Filter for more meaningful words (longer words, avoid common terms)
        const meaningfulWords = descWords.filter(word => {
          const cleanWord = word.replace(/[^a-zA-Z0-9]/g, '').toLowerCase();
          return cleanWord.length > 4 && 
                 !['with', 'this', 'that', 'from', 'your', 'which', 'about', 'these', 'those', 
                   'then', 'than', 'they', 'them', 'their', 'there', 'where', 'when', 'what', 
                   'have', 'will', 'would', 'could', 'should', 'been', 'being'].includes(cleanWord);
        });
        
        // Use up to 3-4 meaningful words from description
        if (meaningfulWords.length > 0) {
          searchTerms = meaningfulWords.slice(0, 4).join(' ');
        }
      }
      
      // If we couldn't get meaningful terms from description, use title as fallback
      if (!searchTerms && productInfo.title) {
        // Extract key terms from title (remove common words)
        const titleWords = productInfo.title.split(' ');
        const filteredWords = titleWords.filter(word => {
          const cleanWord = word.toLowerCase();
          return cleanWord.length > 2 && 
                 !['the', 'and', 'for', 'with', 'this', 'that', 'from', 'your'].includes(cleanWord);
        });
        
        // Use up to 3 words from the title
        searchTerms = filteredWords.slice(0, 3).join(' ');
      }
      
      // Add category if available and not already in search terms
      if (productInfo.category && 
          productInfo.category.length > 0 && 
          !searchTerms.toLowerCase().includes(productInfo.category.toLowerCase())) {
        searchTerms += ' ' + productInfo.category;
      }
    }
  }
  
  // Add ST-US tag to search
  searchTerms += ' "ST-US"';
  
  // Create direct search URL for the current retailer
  let searchURL = "";
  
  if (currentRetailer === 'amazon') {
    searchURL = `https://www.amazon.com/s?k=${encodeURIComponent(searchTerms)}`;
  } else if (currentRetailer === 'walmart') {
    searchURL = `https://www.walmart.com/search?q=${encodeURIComponent(searchTerms)}`;
  }
  
  return searchURL;
}

// Helper function to extract Walmart product description
function extractWalmartProductDescription() {
  let description = '';
  
  // Multiple selectors for Walmart product description elements
  const descriptionSelectors = [
    '.product-description-container',
    '[data-automation="product-description"]',
    '[data-automation="productDescription"]',
    '.prod-ProductDescription',
    '.d_nWo', // Current selector in 2025
    '.about-product',
    '.specification-table',
    '.product-short-description'
  ];
  
  // Try each selector
  for (const selector of descriptionSelectors) {
    const element = document.querySelector(selector);
    if (element) {
      description += element.textContent.trim() + ' ';
    }
  }
  
  return description;
}

// Improved function to display information directly on the page with custom tariff percentage
function displayTariffInfo(userTariffPercentage = DEFAULT_TARIFF_PERCENTAGE) {
  console.log("Attempting to display tariff info with percentage:", userTariffPercentage);
  const productInfo = extractProductInfo();
  
  if (productInfo && productInfo.success) {
    console.log("Successfully got product info, creating UI...");
    
    // Determine which tariff percentage to use
    let tariffPercentage = userTariffPercentage;
    let isTagged = false;
    let isUSMade = false;
    let countryBreakdown = null;
    let retailer = productInfo.retailer || 'amazon';
    
    // If we found ST tag info, use that instead of user input
    if (productInfo.stTagInfo) {
      isTagged = true;
      isUSMade = productInfo.stTagInfo.isUSMade;
      countryBreakdown = productInfo.stTagInfo.countryBreakdown;
      
      // Only override user input if the tag specifies a tariff
      if (productInfo.stTagInfo.tariffPercentage !== undefined) {
        tariffPercentage = productInfo.stTagInfo.tariffPercentage;
      }
    }
    
    // Calculate price without tariff
    const originalPrice = productInfo.price;
    const tariffMultiplier = 1 + (tariffPercentage / 100);
    const priceWithoutTariff = originalPrice / tariffMultiplier;
    const savings = originalPrice - priceWithoutTariff;
    
    // Create the container for our information display
    const infoBox = document.createElement('div');
    infoBox.id = 'show-tariffs-box';
    infoBox.style.backgroundColor = '#f8f9fa';
    infoBox.style.border = '1px solid #d3d3d3';
    infoBox.style.borderRadius = '8px';
    infoBox.style.padding = '15px';
    infoBox.style.margin = '15px 0';
    infoBox.style.boxShadow = '0 2px 5px rgba(0,0,0,0.1)';
    infoBox.style.position = 'relative';
    infoBox.style.fontFamily = 'Arial, sans-serif';
    infoBox.style.zIndex = '1000';
    
    // Create title bar with appropriate color based on US-made status
    const titleBar = document.createElement('div');
    
    // Use a special green color for US-made products
    if (isUSMade) {
      titleBar.style.backgroundColor = '#4CAF50'; // Green for US made
    } else {
      titleBar.style.backgroundColor = '#0066c0'; // Default blue
    }
    
    titleBar.style.color = 'white';
    titleBar.style.padding = '10px 15px';
    titleBar.style.borderRadius = '7px 7px 0 0';
    titleBar.style.marginBottom = '15px';
    titleBar.style.fontWeight = 'bold';
    titleBar.style.fontSize = '16px';
    
    // Custom title text based on tag status
    if (isUSMade) {
      titleBar.textContent = '🇺🇸 Made in USA - No Tariff!';
    } else if (isTagged) {
      titleBar.textContent = 'Show Tariffs - Verified Info';
    } else {
      titleBar.textContent = 'Show Tariffs';
    }
    
    // Create tariff input section with improved styling
    const inputContainer = document.createElement('div');
    inputContainer.style.display = 'flex';
    inputContainer.style.alignItems = 'center';
    inputContainer.style.marginBottom = '15px';
    inputContainer.style.padding = '12px';
    inputContainer.style.backgroundColor = '#e8f4f8';
    inputContainer.style.borderRadius = '6px';
    
    const inputLabel = document.createElement('label');
    inputLabel.textContent = 'Tariff %: ';
    inputLabel.style.marginRight = '10px';
    inputLabel.style.fontWeight = 'bold';
    
    const input = document.createElement('input');
    input.type = 'number';
    input.id = 'tariff-percentage-box';
    input.min = '0';
    input.step = '0.1';
    input.value = tariffPercentage;
    input.style.width = '80px';
    input.style.padding = '8px';
    input.style.borderRadius = '4px';
    input.style.border = '1px solid #ccc';
    input.style.fontSize = '14px';
    
    // Create update button
    const updateButton = document.createElement('button');
    updateButton.textContent = 'Update';
    updateButton.style.marginLeft = '10px';
    updateButton.style.padding = '8px 12px';
    updateButton.style.backgroundColor = '#0066c0';
    updateButton.style.color = 'white';
    updateButton.style.border = 'none';
    updateButton.style.borderRadius = '4px';
    updateButton.style.cursor = 'pointer';
    updateButton.style.fontWeight = 'bold';
    
    // Disable input if product is tagged with a specific tariff
    if (isTagged && productInfo.stTagInfo.tariffPercentage !== undefined) {
      input.disabled = true;
      input.style.backgroundColor = '#f0f0f0';
      inputLabel.textContent = 'Verified Tariff %: ';
      updateButton.disabled = true;
      updateButton.style.backgroundColor = '#cccccc';
    }
    
    // Add event listener to update button
    updateButton.addEventListener('click', function() {
      const newPercentage = parseFloat(input.value);
      if (!isNaN(newPercentage) && newPercentage >= 0) {
        // Update calculations
        updateCalculations(originalPrice, newPercentage);
      }
    });
    
    inputContainer.appendChild(inputLabel);
    inputContainer.appendChild(input);
    inputContainer.appendChild(updateButton);
    
    // Create content container
    const content = document.createElement('div');
    content.id = 'tariff-calculations';
    content.style.backgroundColor = 'white';
    content.style.padding = '15px';
    content.style.borderRadius = '6px';
    content.style.boxShadow = '0 1px 3px rgba(0,0,0,0.05)';
    
    // Function to update calculations when tariff percentage changes
    function updateCalculations(price, percentage) {
      const calculatedMultiplier = 1 + (percentage / 100);
      const calculatedWithoutTariff = price / calculatedMultiplier;
      const calculatedSavings = price - calculatedWithoutTariff;
      
      // Update the displayed values
      content.innerHTML = `
        <p style="margin: 8px 0;"><strong>Current Price:</strong> $${price.toFixed(2)}</p>
        <p style="margin: 8px 0;"><strong>Tariff Rate:</strong> ${percentage}%</p>
        <p style="margin: 8px 0;"><strong>Price Without Tariff:</strong> $${calculatedWithoutTariff.toFixed(2)}</p>
        <p style="margin: 12px 0; color: #388e3c; font-weight: bold; font-size: 16px; background-color: #f1f8e9; padding: 10px; border-radius: 4px;">
          <strong>You might be paying an extra:</strong> $${calculatedSavings.toFixed(2)}
        </p>
      `;
      
      // Add country breakdown if available
      if (countryBreakdown && countryBreakdown.length > 0) {
        let breakdownHTML = '<div style="margin-top: 15px; padding-top: 10px; border-top: 1px solid #ddd;">';
        breakdownHTML += '<p style="margin: 8px 0;"><strong>Product Origin Breakdown:</strong></p>';
        breakdownHTML += '<ul style="margin-top: 5px; padding-left: 20px;">';
        
        // Country code mapping for common countries
        const countryMap = {
          'US': '🇺🇸 United States',
          'CN': '🇨🇳 China',
          'JP': '🇯🇵 Japan',
          'MX': '🇲🇽 Mexico',
          'CA': '🇨🇦 Canada',
          'VN': '🇻🇳 Vietnam',
          'TW': '🇹🇼 Taiwan',
          'KR': '🇰🇷 South Korea',
          'MY': '🇲🇾 Malaysia',
          'TH': '🇹🇭 Thailand'
        };
        
        countryBreakdown.forEach(country => {
          // Get country name if available, otherwise just use code
          const countryDisplay = countryMap[country.countryCode] || `${country.countryCode}`;
          breakdownHTML += `<li style="margin: 4px 0;">${countryDisplay}: ${country.percentage}%</li>`;
        });
        
        breakdownHTML += '</ul></div>';
        content.innerHTML += breakdownHTML;
      }
      
      // Add direct search link if not US-made - KEEPING USER ON CURRENT SITE
      if (!isUSMade) {
        // Create the search URL using the current retailer
        const searchURL = createDirectSearchURL(productInfo);
        
        const searchHTML = `
          <div style="margin-top: 15px; text-align: center;">
            <a href="${searchURL}" style="display: inline-block; background-color: #4CAF50; color: white; padding: 10px 15px; border-radius: 4px; text-decoration: none; font-weight: bold; box-shadow: 0 2px 4px rgba(0,0,0,0.2);">
              🇺🇸 Find US-Made Alternatives
            </a>
          </div>
        `;
        
        content.innerHTML += searchHTML;
      }
    }
    
    // Initial calculation display
    updateCalculations(originalPrice, tariffPercentage);
    
    // Create tag info section with improved styling
    let tagInfoSection = null;
    if (isTagged) {
      tagInfoSection = document.createElement('div');
      tagInfoSection.style.backgroundColor = '#f0f8ff';
      tagInfoSection.style.padding = '12px';
      tagInfoSection.style.marginTop = '15px';
      tagInfoSection.style.borderRadius = '6px';
      tagInfoSection.style.fontSize = '14px';
      tagInfoSection.style.lineHeight = '1.4';
      
      if (isUSMade) {
        tagInfoSection.innerHTML = `
          <p style="margin: 5px 0;"><strong>🇺🇸 US-Made Product</strong></p>
          <p style="margin: 5px 0;">This product is manufactured in the United States and is not subject to import tariffs.</p>
          <p style="margin: 5px 0;">Thank you for supporting American manufacturing!</p>
        `;
      } else {
        tagInfoSection.innerHTML = `
          <p style="margin: 5px 0;"><strong>✓ Verified Tariff Information</strong></p>
          <p style="margin: 5px 0;">This retailer has provided transparent tariff information using our ST tag system.</p>
        `;
      }
    } else {
      tagInfoSection = document.createElement('div');
      tagInfoSection.style.backgroundColor = '#fff8e1';
      tagInfoSection.style.padding = '12px';
      tagInfoSection.style.marginTop = '15px';
      tagInfoSection.style.borderRadius = '6px';
      tagInfoSection.style.fontSize = '14px';
      tagInfoSection.style.lineHeight = '1.4';
      tagInfoSection.innerHTML = `
        <p style="margin: 5px 0;"><strong>ⓘ Estimated Calculation</strong></p>
        <p style="margin: 5px 0;">This retailer hasn't provided verified tariff information. The calculation above uses our default ${userTariffPercentage}% tariff rate.</p>
        <p style="margin: 5px 0;">Learn more at <a href="https://showtariffs.com" target="_blank" style="color: #0066c0; text-decoration: none; font-weight: bold;">ShowTariffs.com</a></p>
      `;
    }
    
    // Add a logo/branding footer
    const footerDiv = document.createElement('div');
    footerDiv.style.marginTop = '15px';
    footerDiv.style.textAlign = 'center';
    footerDiv.style.fontSize = '12px';
    footerDiv.style.color = '#777';
    footerDiv.innerHTML = `
      <a href="https://showtariffs.com" target="_blank" style="text-decoration: none; color: #0066c0;">
        Show Tariffs
      </a> • Revealing true prices without import tariffs
    `;
    
    // Add close button
    const closeButton = document.createElement('button');
    closeButton.style.position = 'absolute';
    closeButton.style.top = '8px';
    closeButton.style.right = '10px';
    closeButton.style.background = 'transparent';
    closeButton.style.border = 'none';
    closeButton.style.color = 'white';
    closeButton.style.fontSize = '16px';
    closeButton.style.cursor = 'pointer';
    closeButton.style.fontWeight = 'bold';
    closeButton.innerHTML = '✕';
    closeButton.addEventListener('click', function() {
      infoBox.style.display = 'none';
    });
    
    // Add minimize/expand button
    const minimizeButton = document.createElement('button');
    minimizeButton.style.position = 'absolute';
    minimizeButton.style.top = '8px';
    minimizeButton.style.right = '35px';
    minimizeButton.style.background = 'transparent';
    minimizeButton.style.border = 'none';
    minimizeButton.style.color = 'white';
    minimizeButton.style.fontSize = '16px';
    minimizeButton.style.cursor = 'pointer';
    minimizeButton.style.fontWeight = 'bold';
    minimizeButton.innerHTML = '−';
    
    let isMinimized = false;
    minimizeButton.addEventListener('click', function() {
      if (isMinimized) {
        content.style.display = 'block';
        inputContainer.style.display = 'flex';
        tagInfoSection.style.display = 'block';
        footerDiv.style.display = 'block';
        minimizeButton.innerHTML = '−';
        isMinimized = false;
      } else {
        content.style.display = 'none';
        inputContainer.style.display = 'none';
        tagInfoSection.style.display = 'none';
        footerDiv.style.display = 'none';
        minimizeButton.innerHTML = '+';
        isMinimized = true;
      }
    });
    
    // Assemble the components
    infoBox.appendChild(titleBar);
    titleBar.appendChild(closeButton);
    titleBar.appendChild(minimizeButton);
    
    // Don't show input for US-made products
    if (!isUSMade) {
      infoBox.appendChild(inputContainer);
    }
    
    infoBox.appendChild(content);
    infoBox.appendChild(tagInfoSection);
    infoBox.appendChild(footerDiv);
    
    console.log("Finding location to insert box...");
    
    // Find insertion point based on retailer
    let insertSuccessful = false;
    
    if (retailer === 'amazon') {
      // Amazon insertion points
      const priceSection = document.getElementById('corePriceDisplay_desktop_feature_div') || 
                           document.getElementById('price') || 
                           document.getElementById('buybox') ||
                           document.getElementById('corePrice_feature_div');
      
      if (priceSection) {
        console.log("Inserting after Amazon price section");
        priceSection.parentNode.insertBefore(infoBox, priceSection.nextSibling);
        insertSuccessful = true;
      } else {
        // Fallback: Try to insert it near the title
        const titleSection = document.getElementById('titleSection') || 
                             document.getElementById('title_feature_div');
        if (titleSection) {
          console.log("Inserting after Amazon title section");
          titleSection.parentNode.insertBefore(infoBox, titleSection.nextSibling);
          insertSuccessful = true;
        }
      }
    } else if (retailer === 'walmart') {
      // Walmart insertion points
      const walmartPriceSelectors = [
        '[data-automation="buybox-price-section"]',
        '.price-box',
        '.prod-PriceSection',
        '.hide-content-max-m.prod-ProductCTA--primary'
      ];
      
      // Try each Walmart price section selector
      for (const selector of walmartPriceSelectors) {
        const priceSection = document.querySelector(selector);
        if (priceSection) {
          console.log("Inserting after Walmart price section");
          priceSection.parentNode.insertBefore(infoBox, priceSection.nextSibling);
          insertSuccessful = true;
          break;
        }
      }
      
      // If price section not found, try product detail area
      if (!insertSuccessful) {
        const detailSelectors = [
          '.product-details-container',
          '[data-automation="product-details"]',
          '.prod-ProductDetails',
          '.buy-box-column'
        ];
        
        for (const selector of detailSelectors) {
          const detailSection = document.querySelector(selector);
          if (detailSection) {
            console.log("Inserting in Walmart product details");
            detailSection.prepend(infoBox);
            insertSuccessful = true;
            break;
          }
        }
      }
    }
    
    // Last resort - insert at top of page
    if (!insertSuccessful) {
      console.log("No insertion points found, adding to top of body");
      document.body.insertBefore(infoBox, document.body.firstChild);
    }
    
    console.log("Tariff info box added to page");
    
    // Add a "draggable" feature to allow users to move the box
    makeElementDraggable(infoBox, titleBar);
    
    // Focus on the input field with a slight delay (for better UX)
    if (!isUSMade && !input.disabled) {
      setTimeout(() => {
        try {
          document.getElementById('tariff-percentage-box').focus();
        } catch (e) {
          console.log("Could not focus on input field:", e);
        }
      }, 500);
    }
  } else {
    console.log("Could not display tariff info, product info extraction failed");
    
    // Create a simple error notification
    const errorBox = document.createElement('div');
    errorBox.id = 'show-tariffs-box';
    errorBox.style.backgroundColor = '#fff3f3';
    errorBox.style.border = '1px solid #ffcccc';
    errorBox.style.borderRadius = '8px';
    errorBox.style.padding = '15px';
    errorBox.style.margin = '15px 0';
    errorBox.style.boxShadow = '0 2px 5px rgba(0,0,0,0.1)';
    errorBox.style.fontFamily = 'Arial, sans-serif';
    errorBox.style.maxWidth = '400px';
    errorBox.style.zIndex = '1000';
    
    errorBox.innerHTML = `
      <div style="color: #d32f2f; font-weight: bold; margin-bottom: 10px;">Show Tariffs</div>
      <p>Could not extract product information. This might not be a compatible product page.</p>
      <p style="margin-top: 10px;">
        <a href="https://showtariffs.com" target="_blank" style="color: #0066c0; text-decoration: none;">Learn more at ShowTariffs.com</a>
      </p>
    `;
    
    // Add close button
    const closeButton = document.createElement('button');
    closeButton.style.float = 'right';
    closeButton.style.background = 'transparent';
    closeButton.style.border = 'none';
    closeButton.style.color = '#d32f2f';
    closeButton.style.fontSize = '16px';
    closeButton.style.cursor = 'pointer';
    closeButton.innerHTML = '✕';
    closeButton.addEventListener('click', function() {
      errorBox.style.display = 'none';
    });
    
    errorBox.prepend(closeButton);
    
    // Insert at top of page
    document.body.insertBefore(errorBox, document.body.firstChild);
  }
}

// Function to make an element draggable
function makeElementDraggable(element, handle) {
  let pos1 = 0, pos2 = 0, pos3 = 0, pos4 = 0;
  
  handle.style.cursor = 'move';
  handle.addEventListener('mousedown', dragMouseDown);
  
  function dragMouseDown(e) {
    e.preventDefault();
    // Get the mouse cursor position at startup
    pos3 = e.clientX;
    pos4 = e.clientY;
    document.addEventListener('mouseup', closeDragElement);
    document.addEventListener('mousemove', elementDrag);
  }
  
  function elementDrag(e) {
    e.preventDefault();
    // Calculate the new cursor position
    pos1 = pos3 - e.clientX;
    pos2 = pos4 - e.clientY;
    pos3 = e.clientX;
    pos4 = e.clientY;
    // Set the element's new position
    element.style.position = 'fixed';
    element.style.top = (element.offsetTop - pos2) + "px";
    element.style.left = (element.offsetLeft - pos1) + "px";
    element.style.zIndex = '9999';
  }
  
  function closeDragElement() {
    // Stop moving when mouse button is released
    document.removeEventListener('mouseup', closeDragElement);
    document.removeEventListener('mousemove', elementDrag);
  }
}

// Function to add a "Show Tariffs" button that the user can click to display info
function addShowTariffsButton() {
  // Check if button already exists
  if (document.getElementById('show-tariffs-button')) {
    return;
  }
  
  const button = document.createElement('button');
  button.id = 'show-tariffs-button';
  button.textContent = 'Show Tariffs Info';
  button.style.backgroundColor = '#0066c0';
  button.style.color = 'white';
  button.style.border = 'none';
  button.style.borderRadius = '4px';
  button.style.padding = '8px 15px';
  button.style.margin = '10px 0';
  button.style.cursor = 'pointer';
  button.style.fontWeight = 'bold';
  button.style.boxShadow = '0 1px 3px rgba(0,0,0,0.1)';
  
  button.addEventListener('click', function() {
    displayTariffInfo(DEFAULT_TARIFF_PERCENTAGE);
  });
  
  let insertSuccessful = false;
  
  // Try to find a good place to insert the button based on retailer
  if (isAmazonProductPage()) {
    const priceSection = document.getElementById('corePriceDisplay_desktop_feature_div') || 
                       document.getElementById('price') || 
                       document.getElementById('buybox') ||
                       document.getElementById('corePrice_feature_div');
  
    if (priceSection) {
      // Insert after the price section
      priceSection.parentNode.insertBefore(button, priceSection.nextSibling);
      insertSuccessful = true;
    }
  } else if (isWalmartProductPage()) {
    const walmartPriceSelectors = [
      '[data-automation="buybox-price-section"]',
      '.price-box',
      '.prod-PriceSection',
      '.hide-content-max-m.prod-ProductCTA--primary'
    ];
    
    // Try each Walmart price section selector
    for (const selector of walmartPriceSelectors) {
      const priceSection = document.querySelector(selector);
      if (priceSection) {
        priceSection.parentNode.insertBefore(button, priceSection.nextSibling);
        insertSuccessful = true;
        break;
      }
    }
  }
  
  // If no suitable location found, add to top of page
  if (!insertSuccessful) {
    document.body.insertBefore(button, document.body.firstChild);
  }
}

// Check if this is an Amazon product page
function isAmazonProductPage() {
  const url = window.location.href;
  return url.includes('amazon.com') && 
         (url.includes('/dp/') || url.includes('/gp/product/'));
}

// Check if this is a Walmart product page using page elements
function isWalmartProductPage() {
  // First check if we're on walmart.com
  const url = window.location.href;
  if (!url.includes('walmart.com')) {
    return false;
  }
  
  // Look for signature Walmart product page elements
  const walmartProductElements = [
    // Product title elements
    'h1[itemprop="name"]',
    'h1.prod-ProductTitle',
    'h1.f3',
    'h1.b lh-copy',
    'h1.w_Y_vW',
    'h1[data-automation="product-title"]',
    
    // Price elements
    '[data-automation="current-price"]',
    '[data-automation="product-price"]',
    '[data-automation="buybox-price"]',
    '.price-characteristic',
    
    // Product description elements
    '.product-description-container',
    '[data-automation="product-description"]',
    '[data-automation="productDescription"]',
    '.prod-ProductDescription',
    '.d_nWo',
    
    // Buy box elements
    '.prod-ProductCTA--primary',
    '[data-automation="add-to-cart"]',
    '[data-automation="buy-now"]',
    '.add-to-cart-btn'
  ];
  
  // Return true if any of these elements exist on the page
  for (const selector of walmartProductElements) {
    if (document.querySelector(selector)) {
      return true;
    }
  }
  
  // Additional check: If URL contains /ip/ and we have a product title and price
  if (url.includes('/ip/')) {
    const hasTitle = document.querySelector('h1');
    const hasPrice = document.querySelector('[itemprop="price"]') || 
                    document.querySelector('.price') || 
                    document.querySelector('[data-testid="price"]');
    
    if (hasTitle && hasPrice) {
      return true;
    }
  }
  
  return false;
}

// Check if this is any supported product page
function isProductPage() {
  return isAmazonProductPage() || isWalmartProductPage();
}

console.log("Show Tariffs content script loaded");

// Run when the page is loaded
window.addEventListener('load', function() {
  if (isProductPage()) {
    console.log("Product page detected");
    
    // Always auto-display since we can't store settings
    if (AUTO_DISPLAY) {
      console.log("Auto-displaying tariff info");
      // Use a delay to ensure the page is fully loaded
      setTimeout(function() {
        displayTariffInfo(DEFAULT_TARIFF_PERCENTAGE);
      }, 2000);
    } else {
      console.log("Adding show tariffs button");
      addShowTariffsButton();
    }
  } else {
    console.log("Not a supported product page, not showing tariff info");
  }
});
