// Event listener for DOMContentLoaded to ensure the popup is fully loaded
document.addEventListener('DOMContentLoaded', function() {
  console.log("Popup loaded");
  
  // Default settings (hardcoded)
  const DEFAULT_TARIFF_PERCENTAGE = 125;
  
  // Get references to DOM elements
  const statusDiv = document.getElementById('status');
  const resultDiv = document.getElementById('result');
  const tariffInput = document.getElementById('tariff-percentage');
  const applyButton = document.getElementById('apply-button');
  const defaultTariffInput = document.getElementById('default-tariff');
  const saveDefaultsButton = document.getElementById('save-defaults');
  const autoDisplayCheckbox = document.getElementById('auto-display');
  const showButtonCheckbox = document.getElementById('show-button');
  
  // US-Made search elements
  const usMadeSearchInput = document.getElementById('us-made-search-input');
  const searchAmazonButton = document.getElementById('search-amazon-button');
  const searchWalmartButton = document.getElementById('search-walmart-button');
  const categoryButtons = document.querySelectorAll('.category-button');
  const currentProductSearch = document.getElementById('current-product-search');
  
  // Store current product info
  let currentProductInfo = null;
  
  // Tab functionality
  const tabs = document.querySelectorAll('.tab');
  const tabContents = document.querySelectorAll('.tab-content');
  
  tabs.forEach(tab => {
    tab.addEventListener('click', function() {
      // Remove active class from all tabs
      tabs.forEach(t => t.classList.remove('active'));
      
      // Add active class to clicked tab
      this.classList.add('active');
      
      // Hide all tab contents
      tabContents.forEach(content => content.classList.remove('active'));
      
      // Show the selected tab content
      const tabName = this.getAttribute('data-tab');
      document.getElementById(`${tabName}-tab`).classList.add('active');
    });
  });
  
  // Initialize the UI with defaults
  initializeUI();
  
  // Apply custom tariff when button is clicked
  if (applyButton) {
    applyButton.addEventListener('click', function() {
      console.log("Apply button clicked");
      
      if (!tariffInput) {
        console.error("Cannot access tariff input element");
        return;
      }
      
      const newTariff = parseFloat(tariffInput.value);
      console.log("New tariff value:", newTariff);
      
      if (!isNaN(newTariff) && newTariff >= 0) {
        // Send message to content script to update the display
        chrome.tabs.query({active: true, currentWindow: true}, function(tabs) {
          try {
            const currentUrl = tabs[0].url;
            console.log("Current tab URL:", currentUrl);
            
            if (isProductPage(currentUrl)) {
              console.log("Sending updateTariff message to content script");
              chrome.tabs.sendMessage(tabs[0].id, 
                {action: "updateTariff", tariffPercentage: newTariff}, 
                function(response) {
                  if (chrome.runtime.lastError) {
                    console.log("Content script not ready yet or error:", chrome.runtime.lastError);
                    showError("Please refresh the page and try again.");
                  } else if (response && response.success) {
                    console.log("Page display updated with new tariff");
                    showSuccess("Tariff percentage updated successfully!");
                  }
                }
              );
            } else {
              showError("This is not a product page. Please navigate to an Amazon or Walmart product page and try again.");
            }
            
            // Try to refresh product info
            tryGetProductInfo(newTariff);
          } catch (error) {
            console.error("Error updating page:", error);
            showError("Error updating the page. Please refresh and try again.");
          }
        });
      } else {
        showError("Please enter a valid percentage (0 or greater)");
      }
    });
  }
  
  // Save default settings - without storage, just show a message
  if (saveDefaultsButton) {
    saveDefaultsButton.addEventListener('click', function() {
      showSettingsSaved();
      showInfo("Settings can't be saved permanently since storage is disabled. Values will reset when you close the browser.");
    });
  }
  
  // US-Made search functionality
  // Category buttons
  categoryButtons.forEach(button => {
    button.addEventListener('click', function() {
      usMadeSearchInput.value = this.textContent.trim();
      updateCurrentProductSearch();
    });
  });
  
  // Update search input when typing
  usMadeSearchInput.addEventListener('input', function() {
    updateCurrentProductSearch();
  });
  
  // Search on Amazon button
  searchAmazonButton.addEventListener('click', function() {
    const searchTerms = getSearchTerms();
    if (searchTerms) {
      const amazonSearchUrl = `https://www.amazon.com/s?k=${encodeURIComponent(searchTerms + ' "ST-US"')}`;
      chrome.tabs.create({ url: amazonSearchUrl });
    } else {
      showError("Please enter a search term or select a category.");
    }
  });
  
  // Search on Walmart button
  searchWalmartButton.addEventListener('click', function() {
    const searchTerms = getSearchTerms();
    if (searchTerms) {
      const walmartSearchUrl = `https://www.walmart.com/search?q=${encodeURIComponent(searchTerms + ' "ST-US"')}`;
      chrome.tabs.create({ url: walmartSearchUrl });
    } else {
      showError("Please enter a search term or select a category.");
    }
  });
  
  // Function to get search terms
  function getSearchTerms() {
    // First try the search input
    if (usMadeSearchInput.value.trim()) {
      return usMadeSearchInput.value.trim();
    }
    
    // If empty and we have product info, use the product title/category
    if (currentProductInfo && currentProductInfo.title) {
      // Extract key terms from title (remove common words)
      const titleWords = currentProductInfo.title.split(' ');
      const filteredWords = titleWords.filter(word => 
        word.length > 2 && 
        !['the', 'and', 'for', 'with', 'this', 'that', 'from', 'your'].includes(word.toLowerCase())
      );
      
      // Use up to 3 words from the title
      let searchTerms = filteredWords.slice(0, 3).join(' ');
      
      // Add category if available
      if (currentProductInfo.category && currentProductInfo.category.length > 0) {
        searchTerms += ' ' + currentProductInfo.category;
      }
      
      return searchTerms;
    }
    
    return '';
  }
  
  // Function to update the current product search display
  function updateCurrentProductSearch() {
    const searchTerms = getSearchTerms();
    if (searchTerms) {
      currentProductSearch.textContent = `Search for: "${searchTerms} ST-US"`;
    } else {
      currentProductSearch.textContent = '';
    }
  }
  
  // Function to initialize UI with default values
  function initializeUI() {
    // Set default values
    tariffInput.value = DEFAULT_TARIFF_PERCENTAGE;
    defaultTariffInput.value = DEFAULT_TARIFF_PERCENTAGE;
    autoDisplayCheckbox.checked = true;
    showButtonCheckbox.checked = true;
    
    console.log("UI initialized with defaults");
  }
  
  // Function to show settings saved message
  function showSettingsSaved() {
    const settingsTab = document.getElementById('settings-tab');
    const message = document.createElement('div');
    message.textContent = "Settings applied for this session!";
    message.style.color = "#4CAF50";
    message.style.padding = "10px";
    message.style.marginTop = "15px";
    message.style.backgroundColor = "#f1f8e9";
    message.style.borderRadius = "4px";
    message.style.textAlign = "center";
    message.style.fontWeight = "bold";
    
    // Remove existing messages
    const existingMessage = settingsTab.querySelector('.settings-message');
    if (existingMessage) {
      existingMessage.remove();
    }
    
    message.className = 'settings-message';
    settingsTab.appendChild(message);
    
    // Remove message after 3 seconds
    setTimeout(() => {
      message.remove();
    }, 3000);
  }
  
  // Function to show error message
  function showError(message) {
    statusDiv.textContent = message;
    statusDiv.className = 'error';
    statusDiv.style.display = 'block';
    
    // Hide error after 5 seconds
    setTimeout(() => {
      statusDiv.style.display = 'none';
    }, 5000);
  }
  
  // Function to show success message
  function showSuccess(message) {
    statusDiv.textContent = message;
    statusDiv.className = 'savings';
    statusDiv.style.display = 'block';
    
    // Hide success message after 3 seconds
    setTimeout(() => {
      statusDiv.style.display = 'none';
    }, 3000);
  }
  
  // Function to show info message
  function showInfo(message) {
    const infoBox = document.createElement('div');
    infoBox.textContent = message;
    infoBox.style.backgroundColor = '#e3f2fd';
    infoBox.style.padding = '10px';
    infoBox.style.marginTop = '10px';
    infoBox.style.borderRadius = '4px';
    infoBox.style.color = '#0d47a1';
    infoBox.style.position = 'fixed';
    infoBox.style.bottom = '10px';
    infoBox.style.left = '10px';
    infoBox.style.right = '10px';
    infoBox.style.textAlign = 'center';
    infoBox.style.boxShadow = '0 2px 5px rgba(0,0,0,0.2)';
    infoBox.style.zIndex = '9999';
    
    document.body.appendChild(infoBox);
    
    // Remove info message after 5 seconds
    setTimeout(() => {
      infoBox.style.opacity = '0';
      infoBox.style.transition = 'opacity 0.5s';
      setTimeout(() => {
        infoBox.remove();
      }, 500);
    }, 5000);
  }
  
  // Function to check if URL is a product page (Amazon or Walmart)
  function isProductPage(url) {
    return isAmazonProductPage(url) || isWalmartProductPage(url);
  }
  
  // Function to check if URL is an Amazon product page
  function isAmazonProductPage(url) {
    return url && url.includes('amazon.com') && 
           (url.includes('/dp/') || url.includes('/gp/product/'));
  }
  
  // Function to check if URL is a Walmart product page
  function isWalmartProductPage(url) {
    return url && url.includes('walmart.com') && 
           (url.includes('/ip/') || url.includes('/items/'));
  }
  
  // Try to get product info from the page
  function tryGetProductInfo(tariffPercentage = DEFAULT_TARIFF_PERCENTAGE) {
    chrome.tabs.query({active: true, currentWindow: true}, function(tabs) {
      const currentUrl = tabs[0].url;
      console.log("Getting product info for URL:", currentUrl);
      
      // Only try if we're on a product page
      if (!isProductPage(currentUrl)) {
        statusDiv.textContent = 'Please navigate to an Amazon or Walmart product page to use this extension.';
        statusDiv.className = 'error';
        return;
      }
      
      // Send message to content script
      try {
        console.log("Sending getProductInfo message to content script");
        chrome.tabs.sendMessage(
          tabs[0].id, 
          {action: "getProductInfo"}, 
          function(response) {
            // Handle possible communication error
            if (chrome.runtime.lastError) {
              console.log("Content script not ready or error:", chrome.runtime.lastError);
              statusDiv.textContent = 'Extension is working, but content script is not ready on this page yet. Try refreshing the page.';
              statusDiv.className = 'loading';
              return;
            }
            
            console.log("Received response from content script:", response);
            
            // Process response
            if (response && response.success) {
              // Store the product info for potential US-made searches
              currentProductInfo = response;
              
              // Pre-fill the US-made search input with product title 
              // if it's not already filled
              if (usMadeSearchInput && !usMadeSearchInput.value && response.title) {
                // Extract main keywords (up to 3 words)
                const words = response.title.split(' ');
                const searchKeywords = words.slice(0, 3).join(' ');
                usMadeSearchInput.value = searchKeywords;
                updateCurrentProductSearch();
              }
              
              // Update the display with the product info
              updateDisplay(response, tariffPercentage);
            } else {
              statusDiv.textContent = 'Could not extract product information. Try refreshing the page.';
              statusDiv.className = 'error';
            }
          }
        );
      } catch (error) {
        console.error("Error sending message:", error);
        statusDiv.textContent = 'Error communicating with the page. Try refreshing.';
        statusDiv.className = 'error';
      }
    });
  }
  
  // Function to update the display with product info
  function updateDisplay(productInfo, tariffPercentage) {
    console.log("Updating display with product info:", productInfo);
    
    // Calculate price without tariff
    const originalPrice = productInfo.price;
    const tariffMultiplier = 1 + (tariffPercentage / 100);
    const priceWithoutTariff = originalPrice / tariffMultiplier;
    const savings = originalPrice - priceWithoutTariff;
    
    console.log("Calculation results:", {
      originalPrice,
      tariffMultiplier,
      priceWithoutTariff,
      savings
    });
    
    // Display results
    statusDiv.style.display = 'none';
    resultDiv.style.display = 'block';
    
    // Get retailer name
    const retailerName = productInfo.retailer === 'walmart' ? 'Walmart' : 'Amazon';
    
    // Base product info
    let resultHTML = `
      <p><strong>Retailer:</strong> ${retailerName}</p>
      <p><strong>Product:</strong> ${truncateText(productInfo.title || 'Product', 50)}</p>
      <p><strong>Current Price:</strong> $${originalPrice.toFixed(2)}</p>
      <p><strong>Tariff Rate:</strong> ${tariffPercentage}%</p>
      <p><strong>Price Without Tariff:</strong> $${priceWithoutTariff.toFixed(2)}</p>
      <div class="savings"><strong>You might be paying an extra:</strong> $${savings.toFixed(2)}</div>
    `;
    
    // Add ASIN if available (Amazon)
    if (productInfo.asin) {
      resultHTML += `<p><strong>Product ASIN:</strong> ${productInfo.asin}</p>`;
    }
    
    // Add Item ID if available (Walmart)
    if (productInfo.itemId) {
      resultHTML += `<p><strong>Product Item ID:</strong> ${productInfo.itemId}</p>`;
    }
    
    // Add ST tag info if available
    if (productInfo.stTagInfo) {
      resultHTML += `<div class="st-tag-info">`;
      
      if (productInfo.stTagInfo.isUSMade) {
        resultHTML += `
          <div class="st-tag-title">🇺🇸 Made in USA - No Tariff</div>
          <p>This product is manufactured in the United States and is not subject to import tariffs.</p>
        `;
      } else {
        resultHTML += `
          <div class="st-tag-title">✓ Verified Tariff Information</div>
          <p>This retailer has provided transparent tariff information using our ST tag system.</p>
        `;
        
        // Add country breakdown if available
        if (productInfo.stTagInfo.countryBreakdown && productInfo.stTagInfo.countryBreakdown.length > 0) {
          resultHTML += `<div class="country-breakdown"><strong>Product Origin:</strong>`;
          
          // Country code mapping for common countries
          const countryMap = {
            'US': '🇺🇸 United States',
            'CN': '🇨🇳 China',
            'JP': '🇯🇵 Japan',
            'MX': '🇲🇽 Mexico',
            'CA': '🇨🇦 Canada',
            'VN': '🇻🇳 Vietnam',
            'TW': '🇹🇼 Taiwan',
            'KR': '🇰🇷 South Korea',
            'MY': '🇲🇾 Malaysia',
            'TH': '🇹🇭 Thailand'
          };
          
          productInfo.stTagInfo.countryBreakdown.forEach(country => {
            // Get country name if available, otherwise just use code
            const countryDisplay = countryMap[country.countryCode] || `${country.countryCode}`;
            resultHTML += `
              <div class="country-item">
                <span class="country-percentage">${country.percentage}%</span> ${countryDisplay}
              </div>
            `;
          });
          
          resultHTML += `</div>`;
        }
      }
      
      resultHTML += `</div>`;
    }
    
    // Add US-Made search button if product is not US-made
    if (!productInfo.stTagInfo || !productInfo.stTagInfo.isUSMade) {
      resultHTML += `
        <div style="margin-top: 15px; text-align: center;">
          <a href="#" id="find-us-made-btn" style="display: inline-block; background-color: #4CAF50; color: white; padding: 8px 12px; border-radius: 4px; text-decoration: none; font-weight: bold;">
            🇺🇸 Find US-Made Alternatives
          </a>
        </div>
      `;
    }
    
    resultDiv.innerHTML = resultHTML;
    
    // Add event listener to the US-Made button if it exists
    const findUSMadeBtn = document.getElementById('find-us-made-btn');
    if (findUSMadeBtn) {
      findUSMadeBtn.addEventListener('click', function(e) {
        e.preventDefault();
        // Switch to US-Made tab
        tabs.forEach(t => t.classList.remove('active'));
        document.querySelector('[data-tab="us-made"]').classList.add('active');
        
        // Show the US-Made tab content
        tabContents.forEach(content => content.classList.remove('active'));
        document.getElementById('us-made-tab').classList.add('active');
      });
    }
  }
  
  // Function to truncate text with ellipsis
  function truncateText(text, maxLength) {
    if (text.length <= maxLength) {
      return text;
    }
    return text.substring(0, maxLength) + '...';
  }
  
  // Try to get product info when popup opens
  console.log("Attempting to get product info");
  tryGetProductInfo(DEFAULT_TARIFF_PERCENTAGE);
});